"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Sql_Servers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVERS_FIELD_NUMBER: builtins.int
    SERVERS_ADMINISTRATORS_FIELD_NUMBER: builtins.int
    SERVERS_AUDITING_SETTINGS_FIELD_NUMBER: builtins.int
    SERVERS_ELASTIC_POOLS_FIELD_NUMBER: builtins.int
    SERVERS_ENCRYPTION_PROTECTOR_FIELD_NUMBER: builtins.int
    SERVERS_EXTENDED_AUDITING_SETTINGS_FIELD_NUMBER: builtins.int
    SERVERS_FAILOVER_GROUPS_FIELD_NUMBER: builtins.int
    SERVERS_FIREWALL_RULES_FIELD_NUMBER: builtins.int
    SERVERS_JOB_AGENTS_FIELD_NUMBER: builtins.int
    SERVERS_JOB_AGENTS_CREDENTIALS_FIELD_NUMBER: builtins.int
    SERVERS_KEYS_FIELD_NUMBER: builtins.int
    SERVERS_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    SERVERS_SECURITY_ALERT_POLICIES_FIELD_NUMBER: builtins.int
    SERVERS_VIRTUAL_NETWORK_RULES_FIELD_NUMBER: builtins.int
    SERVERS_VULNERABILITY_ASSESSMENTS_FIELD_NUMBER: builtins.int
    @property
    def servers(self) -> global___Servers: ...
    @property
    def servers_administrators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersAdministrators]: ...
    @property
    def servers_auditing_settings(self) -> global___ServersAuditingSettings: ...
    @property
    def servers_elastic_pools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersElasticPools]: ...
    @property
    def servers_encryption_protector(self) -> global___ServersEncryptionProtector: ...
    @property
    def servers_extended_auditing_settings(self) -> global___ServersExtendedAuditingSettings: ...
    @property
    def servers_failover_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersFailoverGroups]: ...
    @property
    def servers_firewall_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersFirewallRules]: ...
    @property
    def servers_job_agents(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersJobAgents]: ...
    @property
    def servers_job_agents_credentials(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersJobAgentsCredentials]: ...
    @property
    def servers_keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersKeys]: ...
    @property
    def servers_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersPrivateEndpointConnections]: ...
    @property
    def servers_security_alert_policies(self) -> global___ServersSecurityAlertPolicies: ...
    @property
    def servers_virtual_network_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersVirtualNetworkRules]: ...
    @property
    def servers_vulnerability_assessments(self) -> global___ServersVulnerabilityAssessments: ...
    def __init__(
        self,
        *,
        servers: global___Servers | None = ...,
        servers_administrators: collections.abc.Iterable[global___ServersAdministrators] | None = ...,
        servers_auditing_settings: global___ServersAuditingSettings | None = ...,
        servers_elastic_pools: collections.abc.Iterable[global___ServersElasticPools] | None = ...,
        servers_encryption_protector: global___ServersEncryptionProtector | None = ...,
        servers_extended_auditing_settings: global___ServersExtendedAuditingSettings | None = ...,
        servers_failover_groups: collections.abc.Iterable[global___ServersFailoverGroups] | None = ...,
        servers_firewall_rules: collections.abc.Iterable[global___ServersFirewallRules] | None = ...,
        servers_job_agents: collections.abc.Iterable[global___ServersJobAgents] | None = ...,
        servers_job_agents_credentials: collections.abc.Iterable[global___ServersJobAgentsCredentials] | None = ...,
        servers_keys: collections.abc.Iterable[global___ServersKeys] | None = ...,
        servers_private_endpoint_connections: collections.abc.Iterable[global___ServersPrivateEndpointConnections] | None = ...,
        servers_security_alert_policies: global___ServersSecurityAlertPolicies | None = ...,
        servers_virtual_network_rules: collections.abc.Iterable[global___ServersVirtualNetworkRules] | None = ...,
        servers_vulnerability_assessments: global___ServersVulnerabilityAssessments | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["servers", b"servers", "servers_auditing_settings", b"servers_auditing_settings", "servers_encryption_protector", b"servers_encryption_protector", "servers_extended_auditing_settings", b"servers_extended_auditing_settings", "servers_security_alert_policies", b"servers_security_alert_policies", "servers_vulnerability_assessments", b"servers_vulnerability_assessments"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["servers", b"servers", "servers_administrators", b"servers_administrators", "servers_auditing_settings", b"servers_auditing_settings", "servers_elastic_pools", b"servers_elastic_pools", "servers_encryption_protector", b"servers_encryption_protector", "servers_extended_auditing_settings", b"servers_extended_auditing_settings", "servers_failover_groups", b"servers_failover_groups", "servers_firewall_rules", b"servers_firewall_rules", "servers_job_agents", b"servers_job_agents", "servers_job_agents_credentials", b"servers_job_agents_credentials", "servers_keys", b"servers_keys", "servers_private_endpoint_connections", b"servers_private_endpoint_connections", "servers_security_alert_policies", b"servers_security_alert_policies", "servers_virtual_network_rules", b"servers_virtual_network_rules", "servers_vulnerability_assessments", b"servers_vulnerability_assessments"]) -> None: ...

global___Microsoft_Sql_Servers = Microsoft_Sql_Servers

@typing_extensions.final
class ServersVulnerabilityAssessments(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RECURRING_SCANS_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_ACCESS_KEY_FIELD_NUMBER: builtins.int
    STORAGE_CONTAINER_PATH_FIELD_NUMBER: builtins.int
    STORAGE_CONTAINER_SAS_KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def recurring_scans(self) -> global___VulnerabilityAssessmentRecurringScansProperties: ...
    storage_account_access_key: builtins.str
    storage_container_path: builtins.str
    storage_container_sas_key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        recurring_scans: global___VulnerabilityAssessmentRecurringScansProperties | None = ...,
        storage_account_access_key: builtins.str = ...,
        storage_container_path: builtins.str = ...,
        storage_container_sas_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["recurring_scans", b"recurring_scans", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "recurring_scans", b"recurring_scans", "resource_info", b"resource_info", "storage_account_access_key", b"storage_account_access_key", "storage_container_path", b"storage_container_path", "storage_container_sas_key", b"storage_container_sas_key"]) -> None: ...

global___ServersVulnerabilityAssessments = ServersVulnerabilityAssessments

@typing_extensions.final
class VulnerabilityAssessmentRecurringScansProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMAILS_FIELD_NUMBER: builtins.int
    EMAIL_SUBSCRIPTION_ADMINS_FIELD_NUMBER: builtins.int
    IS_ENABLED_FIELD_NUMBER: builtins.int
    @property
    def emails(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    email_subscription_admins: builtins.bool
    is_enabled: builtins.bool
    def __init__(
        self,
        *,
        emails: collections.abc.Iterable[builtins.str] | None = ...,
        email_subscription_admins: builtins.bool = ...,
        is_enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["email_subscription_admins", b"email_subscription_admins", "emails", b"emails", "is_enabled", b"is_enabled"]) -> None: ...

global___VulnerabilityAssessmentRecurringScansProperties = VulnerabilityAssessmentRecurringScansProperties

@typing_extensions.final
class ServersVirtualNetworkRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IGNORE_MISSING_VNET_SERVICE_ENDPOINT_FIELD_NUMBER: builtins.int
    VIRTUAL_NETWORK_SUBNET_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    ignore_missing_vnet_service_endpoint: builtins.bool
    virtual_network_subnet_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        ignore_missing_vnet_service_endpoint: builtins.bool = ...,
        virtual_network_subnet_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ignore_missing_vnet_service_endpoint", b"ignore_missing_vnet_service_endpoint", "name", b"name", "resource_info", b"resource_info", "virtual_network_subnet_id", b"virtual_network_subnet_id"]) -> None: ...

global___ServersVirtualNetworkRules = ServersVirtualNetworkRules

@typing_extensions.final
class ServersSyncAgents(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SYNC_DATABASE_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    sync_database_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        sync_database_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "sync_database_id", b"sync_database_id"]) -> None: ...

global___ServersSyncAgents = ServersSyncAgents

@typing_extensions.final
class ServersSecurityAlertPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DISABLED_ALERTS_FIELD_NUMBER: builtins.int
    EMAIL_ACCOUNT_ADMINS_FIELD_NUMBER: builtins.int
    EMAIL_ADDRESSES_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_ACCESS_KEY_FIELD_NUMBER: builtins.int
    STORAGE_ENDPOINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def disabled_alerts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    email_account_admins: builtins.bool
    @property
    def email_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    retention_days: builtins.int
    state: builtins.str
    storage_account_access_key: builtins.str
    storage_endpoint: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        disabled_alerts: collections.abc.Iterable[builtins.str] | None = ...,
        email_account_admins: builtins.bool = ...,
        email_addresses: collections.abc.Iterable[builtins.str] | None = ...,
        retention_days: builtins.int = ...,
        state: builtins.str = ...,
        storage_account_access_key: builtins.str = ...,
        storage_endpoint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disabled_alerts", b"disabled_alerts", "email_account_admins", b"email_account_admins", "email_addresses", b"email_addresses", "name", b"name", "resource_info", b"resource_info", "retention_days", b"retention_days", "state", b"state", "storage_account_access_key", b"storage_account_access_key", "storage_endpoint", b"storage_endpoint"]) -> None: ...

global___ServersSecurityAlertPolicies = ServersSecurityAlertPolicies

@typing_extensions.final
class ServersPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def private_endpoint(self) -> global___PrivateEndpointProperty: ...
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionStateProperty: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        private_endpoint: global___PrivateEndpointProperty | None = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionStateProperty | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> None: ...

global___ServersPrivateEndpointConnections = ServersPrivateEndpointConnections

@typing_extensions.final
class PrivateLinkServiceConnectionStateProperty(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    description: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "status", b"status"]) -> None: ...

global___PrivateLinkServiceConnectionStateProperty = PrivateLinkServiceConnectionStateProperty

@typing_extensions.final
class PrivateEndpointProperty(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___PrivateEndpointProperty = PrivateEndpointProperty

@typing_extensions.final
class ServersOutboundFirewallRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServersOutboundFirewallRules = ServersOutboundFirewallRules

@typing_extensions.final
class ServersKeys(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SERVER_KEY_TYPE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    THUMBPRINT_FIELD_NUMBER: builtins.int
    CREATION_DATE_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    server_key_type: builtins.str
    uri: builtins.str
    thumbprint: builtins.str
    creation_date: builtins.str
    kind: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        server_key_type: builtins.str = ...,
        uri: builtins.str = ...,
        thumbprint: builtins.str = ...,
        creation_date: builtins.str = ...,
        kind: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_date", b"creation_date", "kind", b"kind", "name", b"name", "resource_info", b"resource_info", "server_key_type", b"server_key_type", "thumbprint", b"thumbprint", "uri", b"uri"]) -> None: ...

global___ServersKeys = ServersKeys

@typing_extensions.final
class ServersJobAgentsTargetGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JobTarget]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        members: collections.abc.Iterable[global___JobTarget] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["members", b"members", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServersJobAgentsTargetGroups = ServersJobAgentsTargetGroups

@typing_extensions.final
class JobTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_NAME_FIELD_NUMBER: builtins.int
    ELASTIC_POOL_NAME_FIELD_NUMBER: builtins.int
    MEMBERSHIP_TYPE_FIELD_NUMBER: builtins.int
    REFRESH_CREDENTIAL_FIELD_NUMBER: builtins.int
    SERVER_NAME_FIELD_NUMBER: builtins.int
    SHARD_MAP_NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    database_name: builtins.str
    elastic_pool_name: builtins.str
    membership_type: builtins.str
    refresh_credential: builtins.str
    server_name: builtins.str
    shard_map_name: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        database_name: builtins.str = ...,
        elastic_pool_name: builtins.str = ...,
        membership_type: builtins.str = ...,
        refresh_credential: builtins.str = ...,
        server_name: builtins.str = ...,
        shard_map_name: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["database_name", b"database_name", "elastic_pool_name", b"elastic_pool_name", "membership_type", b"membership_type", "refresh_credential", b"refresh_credential", "server_name", b"server_name", "shard_map_name", b"shard_map_name", "type", b"type"]) -> None: ...

global___JobTarget = JobTarget

@typing_extensions.final
class ServersJobAgentsJobsSteps(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    CREDENTIAL_FIELD_NUMBER: builtins.int
    EXECUTION_OPTIONS_FIELD_NUMBER: builtins.int
    OUTPUT_FIELD_NUMBER: builtins.int
    STEP_ID_FIELD_NUMBER: builtins.int
    TARGET_GROUP_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def action(self) -> global___JobStepAction: ...
    credential: builtins.str
    @property
    def execution_options(self) -> global___JobStepExecutionOptions: ...
    @property
    def output(self) -> global___JobStepOutput: ...
    step_id: builtins.int
    target_group: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        action: global___JobStepAction | None = ...,
        credential: builtins.str = ...,
        execution_options: global___JobStepExecutionOptions | None = ...,
        output: global___JobStepOutput | None = ...,
        step_id: builtins.int = ...,
        target_group: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["action", b"action", "execution_options", b"execution_options", "output", b"output", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "credential", b"credential", "execution_options", b"execution_options", "name", b"name", "output", b"output", "resource_info", b"resource_info", "step_id", b"step_id", "target_group", b"target_group"]) -> None: ...

global___ServersJobAgentsJobsSteps = ServersJobAgentsJobsSteps

@typing_extensions.final
class JobStepOutput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREDENTIAL_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_NAME_FIELD_NUMBER: builtins.int
    SCHEMA_NAME_FIELD_NUMBER: builtins.int
    SERVER_NAME_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_ID_FIELD_NUMBER: builtins.int
    TABLE_NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    credential: builtins.str
    database_name: builtins.str
    resource_group_name: builtins.str
    schema_name: builtins.str
    server_name: builtins.str
    subscription_id: builtins.str
    table_name: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        credential: builtins.str = ...,
        database_name: builtins.str = ...,
        resource_group_name: builtins.str = ...,
        schema_name: builtins.str = ...,
        server_name: builtins.str = ...,
        subscription_id: builtins.str = ...,
        table_name: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["credential", b"credential", "database_name", b"database_name", "resource_group_name", b"resource_group_name", "schema_name", b"schema_name", "server_name", b"server_name", "subscription_id", b"subscription_id", "table_name", b"table_name", "type", b"type"]) -> None: ...

global___JobStepOutput = JobStepOutput

@typing_extensions.final
class JobStepExecutionOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INITIAL_RETRY_INTERVAL_SECONDS_FIELD_NUMBER: builtins.int
    MAXIMUM_RETRY_INTERVAL_SECONDS_FIELD_NUMBER: builtins.int
    RETRY_ATTEMPTS_FIELD_NUMBER: builtins.int
    RETRY_INTERVAL_BACKOFF_MULTIPLIER_FIELD_NUMBER: builtins.int
    TIMEOUT_SECONDS_FIELD_NUMBER: builtins.int
    initial_retry_interval_seconds: builtins.int
    maximum_retry_interval_seconds: builtins.int
    retry_attempts: builtins.int
    retry_interval_backoff_multiplier: builtins.float
    timeout_seconds: builtins.int
    def __init__(
        self,
        *,
        initial_retry_interval_seconds: builtins.int = ...,
        maximum_retry_interval_seconds: builtins.int = ...,
        retry_attempts: builtins.int = ...,
        retry_interval_backoff_multiplier: builtins.float = ...,
        timeout_seconds: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["initial_retry_interval_seconds", b"initial_retry_interval_seconds", "maximum_retry_interval_seconds", b"maximum_retry_interval_seconds", "retry_attempts", b"retry_attempts", "retry_interval_backoff_multiplier", b"retry_interval_backoff_multiplier", "timeout_seconds", b"timeout_seconds"]) -> None: ...

global___JobStepExecutionOptions = JobStepExecutionOptions

@typing_extensions.final
class JobStepAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    source: builtins.str
    type: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        source: builtins.str = ...,
        type: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["source", b"source", "type", b"type", "value", b"value"]) -> None: ...

global___JobStepAction = JobStepAction

@typing_extensions.final
class ServersJobAgentsJobsExecutions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServersJobAgentsJobsExecutions = ServersJobAgentsJobsExecutions

@typing_extensions.final
class ServersJobAgentsJobs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    SERVERS_JOB_AGENTS_JOBS_EXECUTIONS_FIELD_NUMBER: builtins.int
    SERVERS_JOB_AGENTS_JOBS_STEPS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    description: builtins.str
    @property
    def schedule(self) -> global___JobSchedule: ...
    @property
    def servers_job_agents_jobs_executions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersJobAgentsJobsExecutions]: ...
    @property
    def servers_job_agents_jobs_steps(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersJobAgentsJobsSteps]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        schedule: global___JobSchedule | None = ...,
        servers_job_agents_jobs_executions: collections.abc.Iterable[global___ServersJobAgentsJobsExecutions] | None = ...,
        servers_job_agents_jobs_steps: collections.abc.Iterable[global___ServersJobAgentsJobsSteps] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "schedule", b"schedule"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "name", b"name", "resource_info", b"resource_info", "schedule", b"schedule", "servers_job_agents_jobs_executions", b"servers_job_agents_jobs_executions", "servers_job_agents_jobs_steps", b"servers_job_agents_jobs_steps"]) -> None: ...

global___ServersJobAgentsJobs = ServersJobAgentsJobs

@typing_extensions.final
class JobSchedule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    INTERVAL_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    end_time: builtins.str
    interval: builtins.str
    start_time: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        end_time: builtins.str = ...,
        interval: builtins.str = ...,
        start_time: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "end_time", b"end_time", "interval", b"interval", "start_time", b"start_time", "type", b"type"]) -> None: ...

global___JobSchedule = JobSchedule

@typing_extensions.final
class ServersJobAgentsCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    password: builtins.str
    username: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        password: builtins.str = ...,
        username: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "password", b"password", "resource_info", b"resource_info", "username", b"username"]) -> None: ...

global___ServersJobAgentsCredentials = ServersJobAgentsCredentials

@typing_extensions.final
class ServersJobAgents(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DATABASE_ID_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    SERVERS_JOB_AGENTS_JOBS_FIELD_NUMBER: builtins.int
    SERVERS_JOB_AGENTS_TARGET_GROUPS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    database_id: builtins.str
    @property
    def sku(self) -> global___Sku: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def servers_job_agents_jobs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersJobAgentsJobs]: ...
    @property
    def servers_job_agents_target_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersJobAgentsTargetGroups]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        database_id: builtins.str = ...,
        sku: global___Sku | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        servers_job_agents_jobs: collections.abc.Iterable[global___ServersJobAgentsJobs] | None = ...,
        servers_job_agents_target_groups: collections.abc.Iterable[global___ServersJobAgentsTargetGroups] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["database_id", b"database_id", "location", b"location", "name", b"name", "resource_info", b"resource_info", "servers_job_agents_jobs", b"servers_job_agents_jobs", "servers_job_agents_target_groups", b"servers_job_agents_target_groups", "sku", b"sku", "tags", b"tags"]) -> None: ...

global___ServersJobAgents = ServersJobAgents

@typing_extensions.final
class ServersIpv6FirewallRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    END_IPV6_ADDRESS_FIELD_NUMBER: builtins.int
    START_IPV6_ADDRESS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    end_ipv6_address: builtins.str
    start_ipv6_address: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        end_ipv6_address: builtins.str = ...,
        start_ipv6_address: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_ipv6_address", b"end_ipv6_address", "name", b"name", "resource_info", b"resource_info", "start_ipv6_address", b"start_ipv6_address"]) -> None: ...

global___ServersIpv6FirewallRules = ServersIpv6FirewallRules

@typing_extensions.final
class ServersFirewallRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    END_IP_ADDRESS_FIELD_NUMBER: builtins.int
    START_IP_ADDRESS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    end_ip_address: builtins.str
    start_ip_address: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        end_ip_address: builtins.str = ...,
        start_ip_address: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_ip_address", b"end_ip_address", "name", b"name", "resource_info", b"resource_info", "start_ip_address", b"start_ip_address"]) -> None: ...

global___ServersFirewallRules = ServersFirewallRules

@typing_extensions.final
class ServersFailoverGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DATABASES_FIELD_NUMBER: builtins.int
    PARTNER_SERVERS_FIELD_NUMBER: builtins.int
    READ_ONLY_ENDPOINT_FIELD_NUMBER: builtins.int
    READ_WRITE_ENDPOINT_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def databases(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def partner_servers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PartnerInfo]: ...
    @property
    def read_only_endpoint(self) -> global___FailoverGroupReadOnlyEndpoint: ...
    @property
    def read_write_endpoint(self) -> global___FailoverGroupReadWriteEndpoint: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        databases: collections.abc.Iterable[builtins.str] | None = ...,
        partner_servers: collections.abc.Iterable[global___PartnerInfo] | None = ...,
        read_only_endpoint: global___FailoverGroupReadOnlyEndpoint | None = ...,
        read_write_endpoint: global___FailoverGroupReadWriteEndpoint | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["read_only_endpoint", b"read_only_endpoint", "read_write_endpoint", b"read_write_endpoint", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["databases", b"databases", "name", b"name", "partner_servers", b"partner_servers", "read_only_endpoint", b"read_only_endpoint", "read_write_endpoint", b"read_write_endpoint", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___ServersFailoverGroups = ServersFailoverGroups

@typing_extensions.final
class FailoverGroupReadWriteEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FAILOVER_POLICY_FIELD_NUMBER: builtins.int
    FAILOVER_WITH_DATA_LOSS_GRACE_PERIOD_MINUTES_FIELD_NUMBER: builtins.int
    failover_policy: builtins.str
    failover_with_data_loss_grace_period_minutes: builtins.int
    def __init__(
        self,
        *,
        failover_policy: builtins.str = ...,
        failover_with_data_loss_grace_period_minutes: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["failover_policy", b"failover_policy", "failover_with_data_loss_grace_period_minutes", b"failover_with_data_loss_grace_period_minutes"]) -> None: ...

global___FailoverGroupReadWriteEndpoint = FailoverGroupReadWriteEndpoint

@typing_extensions.final
class FailoverGroupReadOnlyEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FAILOVER_POLICY_FIELD_NUMBER: builtins.int
    failover_policy: builtins.str
    def __init__(
        self,
        *,
        failover_policy: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["failover_policy", b"failover_policy"]) -> None: ...

global___FailoverGroupReadOnlyEndpoint = FailoverGroupReadOnlyEndpoint

@typing_extensions.final
class PartnerInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___PartnerInfo = PartnerInfo

@typing_extensions.final
class ServersExtendedAuditingSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUDIT_ACTIONS_AND_GROUPS_FIELD_NUMBER: builtins.int
    IS_AZURE_MONITOR_TARGET_ENABLED_FIELD_NUMBER: builtins.int
    IS_DEVOPS_AUDIT_ENABLED_FIELD_NUMBER: builtins.int
    IS_STORAGE_SECONDARY_KEY_IN_USE_FIELD_NUMBER: builtins.int
    PREDICATE_EXPRESSION_FIELD_NUMBER: builtins.int
    QUEUE_DELAY_MS_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_ACCESS_KEY_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_SUBSCRIPTION_ID_FIELD_NUMBER: builtins.int
    STORAGE_ENDPOINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def audit_actions_and_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    is_azure_monitor_target_enabled: builtins.bool
    is_devops_audit_enabled: builtins.bool
    is_storage_secondary_key_in_use: builtins.bool
    predicate_expression: builtins.str
    queue_delay_ms: builtins.int
    retention_days: builtins.int
    state: builtins.str
    storage_account_access_key: builtins.str
    storage_account_subscription_id: builtins.str
    storage_endpoint: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        audit_actions_and_groups: collections.abc.Iterable[builtins.str] | None = ...,
        is_azure_monitor_target_enabled: builtins.bool = ...,
        is_devops_audit_enabled: builtins.bool = ...,
        is_storage_secondary_key_in_use: builtins.bool = ...,
        predicate_expression: builtins.str = ...,
        queue_delay_ms: builtins.int = ...,
        retention_days: builtins.int = ...,
        state: builtins.str = ...,
        storage_account_access_key: builtins.str = ...,
        storage_account_subscription_id: builtins.str = ...,
        storage_endpoint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audit_actions_and_groups", b"audit_actions_and_groups", "is_azure_monitor_target_enabled", b"is_azure_monitor_target_enabled", "is_devops_audit_enabled", b"is_devops_audit_enabled", "is_storage_secondary_key_in_use", b"is_storage_secondary_key_in_use", "name", b"name", "predicate_expression", b"predicate_expression", "queue_delay_ms", b"queue_delay_ms", "resource_info", b"resource_info", "retention_days", b"retention_days", "state", b"state", "storage_account_access_key", b"storage_account_access_key", "storage_account_subscription_id", b"storage_account_subscription_id", "storage_endpoint", b"storage_endpoint"]) -> None: ...

global___ServersExtendedAuditingSettings = ServersExtendedAuditingSettings

@typing_extensions.final
class ServersEncryptionProtector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTO_ROTATION_ENABLED_FIELD_NUMBER: builtins.int
    SERVER_KEY_NAME_FIELD_NUMBER: builtins.int
    SERVER_KEY_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    auto_rotation_enabled: builtins.bool
    server_key_name: builtins.str
    server_key_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        auto_rotation_enabled: builtins.bool = ...,
        server_key_name: builtins.str = ...,
        server_key_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_rotation_enabled", b"auto_rotation_enabled", "name", b"name", "resource_info", b"resource_info", "server_key_name", b"server_key_name", "server_key_type", b"server_key_type"]) -> None: ...

global___ServersEncryptionProtector = ServersEncryptionProtector

@typing_extensions.final
class ServersElasticPools(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    HIGH_AVAILABILITY_REPLICA_COUNT_FIELD_NUMBER: builtins.int
    LICENSE_TYPE_FIELD_NUMBER: builtins.int
    MAINTENANCE_CONFIGURATION_ID_FIELD_NUMBER: builtins.int
    MAX_SIZE_BYTES_FIELD_NUMBER: builtins.int
    PER_DATABASE_SETTINGS_FIELD_NUMBER: builtins.int
    ZONE_REDUNDANT_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    high_availability_replica_count: builtins.int
    license_type: builtins.str
    maintenance_configuration_id: builtins.str
    max_size_bytes: builtins.int
    @property
    def per_database_settings(self) -> global___ElasticPoolPerDatabaseSettings: ...
    zone_redundant: builtins.bool
    @property
    def sku(self) -> global___Sku: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        high_availability_replica_count: builtins.int = ...,
        license_type: builtins.str = ...,
        maintenance_configuration_id: builtins.str = ...,
        max_size_bytes: builtins.int = ...,
        per_database_settings: global___ElasticPoolPerDatabaseSettings | None = ...,
        zone_redundant: builtins.bool = ...,
        sku: global___Sku | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["per_database_settings", b"per_database_settings", "resource_info", b"resource_info", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["high_availability_replica_count", b"high_availability_replica_count", "license_type", b"license_type", "location", b"location", "maintenance_configuration_id", b"maintenance_configuration_id", "max_size_bytes", b"max_size_bytes", "name", b"name", "per_database_settings", b"per_database_settings", "resource_info", b"resource_info", "sku", b"sku", "tags", b"tags", "zone_redundant", b"zone_redundant"]) -> None: ...

global___ServersElasticPools = ServersElasticPools

@typing_extensions.final
class Sku(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPACITY_FIELD_NUMBER: builtins.int
    FAMILY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    capacity: builtins.int
    family: builtins.str
    name: builtins.str
    size: builtins.str
    tier: builtins.str
    def __init__(
        self,
        *,
        capacity: builtins.int = ...,
        family: builtins.str = ...,
        name: builtins.str = ...,
        size: builtins.str = ...,
        tier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["capacity", b"capacity", "family", b"family", "name", b"name", "size", b"size", "tier", b"tier"]) -> None: ...

global___Sku = Sku

@typing_extensions.final
class ElasticPoolPerDatabaseSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_CAPACITY_FIELD_NUMBER: builtins.int
    MIN_CAPACITY_FIELD_NUMBER: builtins.int
    max_capacity: builtins.float
    min_capacity: builtins.float
    def __init__(
        self,
        *,
        max_capacity: builtins.float = ...,
        min_capacity: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_capacity", b"max_capacity", "min_capacity", b"min_capacity"]) -> None: ...

global___ElasticPoolPerDatabaseSettings = ElasticPoolPerDatabaseSettings

@typing_extensions.final
class ServersDnsAliases(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServersDnsAliases = ServersDnsAliases

@typing_extensions.final
class ServersDevOpsAuditingSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IS_AZURE_MONITOR_TARGET_ENABLED_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_ACCESS_KEY_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_SUBSCRIPTION_ID_FIELD_NUMBER: builtins.int
    STORAGE_ENDPOINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    is_azure_monitor_target_enabled: builtins.bool
    state: builtins.str
    storage_account_access_key: builtins.str
    storage_account_subscription_id: builtins.str
    storage_endpoint: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        is_azure_monitor_target_enabled: builtins.bool = ...,
        state: builtins.str = ...,
        storage_account_access_key: builtins.str = ...,
        storage_account_subscription_id: builtins.str = ...,
        storage_endpoint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_azure_monitor_target_enabled", b"is_azure_monitor_target_enabled", "name", b"name", "resource_info", b"resource_info", "state", b"state", "storage_account_access_key", b"storage_account_access_key", "storage_account_subscription_id", b"storage_account_subscription_id", "storage_endpoint", b"storage_endpoint"]) -> None: ...

global___ServersDevOpsAuditingSettings = ServersDevOpsAuditingSettings

@typing_extensions.final
class ServersConnectionPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONNECTION_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    connection_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        connection_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connection_type", b"connection_type", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServersConnectionPolicies = ServersConnectionPolicies

@typing_extensions.final
class ServersAzureADOnlyAuthentications(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AZURE_AD_ONLY_AUTHENTICATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    azure_ad_only_authentication: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        azure_ad_only_authentication: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["azure_ad_only_authentication", b"azure_ad_only_authentication", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServersAzureADOnlyAuthentications = ServersAzureADOnlyAuthentications

@typing_extensions.final
class ServersAuditingSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUDIT_ACTIONS_AND_GROUPS_FIELD_NUMBER: builtins.int
    IS_AZURE_MONITOR_TARGET_ENABLED_FIELD_NUMBER: builtins.int
    IS_DEVOPS_AUDIT_ENABLED_FIELD_NUMBER: builtins.int
    IS_STORAGE_SECONDARY_KEY_IN_USE_FIELD_NUMBER: builtins.int
    QUEUE_DELAY_MS_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_ACCESS_KEY_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_SUBSCRIPTION_ID_FIELD_NUMBER: builtins.int
    STORAGE_ENDPOINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def audit_actions_and_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    is_azure_monitor_target_enabled: builtins.bool
    is_devops_audit_enabled: builtins.bool
    is_storage_secondary_key_in_use: builtins.bool
    queue_delay_ms: builtins.int
    retention_days: builtins.int
    state: builtins.str
    storage_account_access_key: builtins.str
    storage_account_subscription_id: builtins.str
    storage_endpoint: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        audit_actions_and_groups: collections.abc.Iterable[builtins.str] | None = ...,
        is_azure_monitor_target_enabled: builtins.bool = ...,
        is_devops_audit_enabled: builtins.bool = ...,
        is_storage_secondary_key_in_use: builtins.bool = ...,
        queue_delay_ms: builtins.int = ...,
        retention_days: builtins.int = ...,
        state: builtins.str = ...,
        storage_account_access_key: builtins.str = ...,
        storage_account_subscription_id: builtins.str = ...,
        storage_endpoint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audit_actions_and_groups", b"audit_actions_and_groups", "is_azure_monitor_target_enabled", b"is_azure_monitor_target_enabled", "is_devops_audit_enabled", b"is_devops_audit_enabled", "is_storage_secondary_key_in_use", b"is_storage_secondary_key_in_use", "name", b"name", "queue_delay_ms", b"queue_delay_ms", "resource_info", b"resource_info", "retention_days", b"retention_days", "state", b"state", "storage_account_access_key", b"storage_account_access_key", "storage_account_subscription_id", b"storage_account_subscription_id", "storage_endpoint", b"storage_endpoint"]) -> None: ...

global___ServersAuditingSettings = ServersAuditingSettings

@typing_extensions.final
class ServersAdministrators(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ADMINISTRATOR_TYPE_FIELD_NUMBER: builtins.int
    LOGIN_FIELD_NUMBER: builtins.int
    SID_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    AZURE_AD_ONLY_AUTHENTICATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    administrator_type: builtins.str
    login: builtins.str
    sid: builtins.str
    tenant_id: builtins.str
    azure_ad_only_authentication: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        administrator_type: builtins.str = ...,
        login: builtins.str = ...,
        sid: builtins.str = ...,
        tenant_id: builtins.str = ...,
        azure_ad_only_authentication: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["administrator_type", b"administrator_type", "azure_ad_only_authentication", b"azure_ad_only_authentication", "login", b"login", "name", b"name", "resource_info", b"resource_info", "sid", b"sid", "tenant_id", b"tenant_id"]) -> None: ...

global___ServersAdministrators = ServersAdministrators

@typing_extensions.final
class Servers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ADMINISTRATOR_LOGIN_FIELD_NUMBER: builtins.int
    ADMINISTRATOR_LOGIN_PASSWORD_FIELD_NUMBER: builtins.int
    ADMINISTRATORS_FIELD_NUMBER: builtins.int
    FEDERATED_CLIENT_ID_FIELD_NUMBER: builtins.int
    KEY_ID_FIELD_NUMBER: builtins.int
    MINIMAL_TLS_VERSION_FIELD_NUMBER: builtins.int
    PRIMARY_USER_ASSIGNED_IDENTITY_ID_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    RESTRICT_OUTBOUND_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    SERVERS_IPV6_FIREWALL_RULES_FIELD_NUMBER: builtins.int
    SERVERS_OUTBOUND_FIREWALL_RULES_FIELD_NUMBER: builtins.int
    SERVERS_AZURE_AD_ONLY_AUTHENTICATIONS_FIELD_NUMBER: builtins.int
    SERVERS_CONNECTION_POLICIES_FIELD_NUMBER: builtins.int
    SERVERS_DEV_OPS_AUDITING_SETTINGS_FIELD_NUMBER: builtins.int
    SERVERS_DNS_ALIASES_FIELD_NUMBER: builtins.int
    SERVERS_SYNC_AGENTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ResourceIdentity: ...
    location: builtins.str
    name: builtins.str
    administrator_login: builtins.str
    administrator_login_password: builtins.str
    @property
    def administrators(self) -> global___ServerExternalAdministrator: ...
    federated_client_id: builtins.str
    key_id: builtins.str
    minimal_tls_version: builtins.str
    primary_user_assigned_identity_id: builtins.str
    public_network_access: builtins.str
    restrict_outbound_network_access: builtins.str
    version: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def servers_ipv6_firewall_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersIpv6FirewallRules]: ...
    @property
    def servers_outbound_firewall_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersOutboundFirewallRules]: ...
    @property
    def servers_azure_ad_only_authentications(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersAzureADOnlyAuthentications]: ...
    @property
    def servers_connection_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersConnectionPolicies]: ...
    @property
    def servers_dev_ops_auditing_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersDevOpsAuditingSettings]: ...
    @property
    def servers_dns_aliases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersDnsAliases]: ...
    @property
    def servers_sync_agents(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServersSyncAgents]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ResourceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        administrator_login: builtins.str = ...,
        administrator_login_password: builtins.str = ...,
        administrators: global___ServerExternalAdministrator | None = ...,
        federated_client_id: builtins.str = ...,
        key_id: builtins.str = ...,
        minimal_tls_version: builtins.str = ...,
        primary_user_assigned_identity_id: builtins.str = ...,
        public_network_access: builtins.str = ...,
        restrict_outbound_network_access: builtins.str = ...,
        version: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        servers_ipv6_firewall_rules: collections.abc.Iterable[global___ServersIpv6FirewallRules] | None = ...,
        servers_outbound_firewall_rules: collections.abc.Iterable[global___ServersOutboundFirewallRules] | None = ...,
        servers_azure_ad_only_authentications: collections.abc.Iterable[global___ServersAzureADOnlyAuthentications] | None = ...,
        servers_connection_policies: collections.abc.Iterable[global___ServersConnectionPolicies] | None = ...,
        servers_dev_ops_auditing_settings: collections.abc.Iterable[global___ServersDevOpsAuditingSettings] | None = ...,
        servers_dns_aliases: collections.abc.Iterable[global___ServersDnsAliases] | None = ...,
        servers_sync_agents: collections.abc.Iterable[global___ServersSyncAgents] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["administrators", b"administrators", "identity", b"identity", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["administrator_login", b"administrator_login", "administrator_login_password", b"administrator_login_password", "administrators", b"administrators", "federated_client_id", b"federated_client_id", "identity", b"identity", "key_id", b"key_id", "location", b"location", "minimal_tls_version", b"minimal_tls_version", "name", b"name", "primary_user_assigned_identity_id", b"primary_user_assigned_identity_id", "public_network_access", b"public_network_access", "resource_info", b"resource_info", "restrict_outbound_network_access", b"restrict_outbound_network_access", "servers_azure_ad_only_authentications", b"servers_azure_ad_only_authentications", "servers_connection_policies", b"servers_connection_policies", "servers_dev_ops_auditing_settings", b"servers_dev_ops_auditing_settings", "servers_dns_aliases", b"servers_dns_aliases", "servers_ipv6_firewall_rules", b"servers_ipv6_firewall_rules", "servers_outbound_firewall_rules", b"servers_outbound_firewall_rules", "servers_sync_agents", b"servers_sync_agents", "tags", b"tags", "version", b"version"]) -> None: ...

global___Servers = Servers

@typing_extensions.final
class ServerExternalAdministrator(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADMINISTRATOR_TYPE_FIELD_NUMBER: builtins.int
    AZURE_AD_ONLY_AUTHENTICATION_FIELD_NUMBER: builtins.int
    LOGIN_FIELD_NUMBER: builtins.int
    PRINCIPAL_TYPE_FIELD_NUMBER: builtins.int
    SID_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    administrator_type: builtins.str
    azure_ad_only_authentication: builtins.bool
    login: builtins.str
    principal_type: builtins.str
    sid: builtins.str
    tenant_id: builtins.str
    def __init__(
        self,
        *,
        administrator_type: builtins.str = ...,
        azure_ad_only_authentication: builtins.bool = ...,
        login: builtins.str = ...,
        principal_type: builtins.str = ...,
        sid: builtins.str = ...,
        tenant_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["administrator_type", b"administrator_type", "azure_ad_only_authentication", b"azure_ad_only_authentication", "login", b"login", "principal_type", b"principal_type", "sid", b"sid", "tenant_id", b"tenant_id"]) -> None: ...

global___ServerExternalAdministrator = ServerExternalAdministrator

@typing_extensions.final
class ResourceIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___ResourceIdentity = ResourceIdentity



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.admissionregistration.v1alpha1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEkubernetes/kubernetes_io.k8s.api.admissionregistration.v1alpha1.proto\x12\x32oak9.tython.k8s.api.admissionregistration.v1alpha1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\"\xe2\x03\n\x0eMatchResources\x12k\n\x16\x65xclude_resource_rules\x18\x01 \x03(\x0b\x32K.oak9.tython.k8s.api.admissionregistration.v1alpha1.NamedRuleWithOperations\x12\x14\n\x0cmatch_policy\x18\x02 \x01(\t\x12X\n\x12namespace_selector\x18\x03 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12U\n\x0fobject_selector\x18\x04 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x63\n\x0eresource_rules\x18\x05 \x03(\x0b\x32K.oak9.tython.k8s.api.admissionregistration.v1alpha1.NamedRuleWithOperations\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xca\x01\n\x17NamedRuleWithOperations\x12\x12\n\napi_groups\x18\x01 \x03(\t\x12\x14\n\x0c\x61pi_versions\x18\x02 \x03(\t\x12\x12\n\noperations\x18\x03 \x03(\t\x12\x16\n\x0eresource_names\x18\x04 \x03(\t\x12\x11\n\tresources\x18\x05 \x03(\t\x12\r\n\x05scope\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"g\n\tParamKind\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"d\n\x08ParamRef\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa5\x02\n\x19ValidatingAdmissionPolicy\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12_\n\x04spec\x18\x04 \x01(\x0b\x32Q.oak9.tython.k8s.api.admissionregistration.v1alpha1.ValidatingAdmissionPolicySpec\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb3\x02\n ValidatingAdmissionPolicyBinding\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x66\n\x04spec\x18\x04 \x01(\x0b\x32X.oak9.tython.k8s.api.admissionregistration.v1alpha1.ValidatingAdmissionPolicyBindingSpec\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb2\x02\n$ValidatingAdmissionPolicyBindingList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x63\n\x05items\x18\x02 \x03(\x0b\x32T.oak9.tython.k8s.api.admissionregistration.v1alpha1.ValidatingAdmissionPolicyBinding\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa2\x02\n$ValidatingAdmissionPolicyBindingSpec\x12[\n\x0fmatch_resources\x18\x01 \x01(\x0b\x32\x42.oak9.tython.k8s.api.admissionregistration.v1alpha1.MatchResources\x12O\n\tparam_ref\x18\x02 \x01(\x0b\x32<.oak9.tython.k8s.api.admissionregistration.v1alpha1.ParamRef\x12\x13\n\x0bpolicy_name\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa4\x02\n\x1dValidatingAdmissionPolicyList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\\\n\x05items\x18\x02 \x03(\x0b\x32M.oak9.tython.k8s.api.admissionregistration.v1alpha1.ValidatingAdmissionPolicy\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf7\x02\n\x1dValidatingAdmissionPolicySpec\x12\x16\n\x0e\x66\x61ilure_policy\x18\x01 \x01(\t\x12]\n\x11match_constraints\x18\x02 \x01(\x0b\x32\x42.oak9.tython.k8s.api.admissionregistration.v1alpha1.MatchResources\x12Q\n\nparam_kind\x18\x03 \x01(\x0b\x32=.oak9.tython.k8s.api.admissionregistration.v1alpha1.ParamKind\x12S\n\x0bvalidations\x18\x04 \x03(\x0b\x32>.oak9.tython.k8s.api.admissionregistration.v1alpha1.Validation\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"z\n\nValidation\x12\x12\n\nexpression\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.admissionregistration.v1alpha1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MATCHRESOURCES._serialized_start=213
  _MATCHRESOURCES._serialized_end=695
  _NAMEDRULEWITHOPERATIONS._serialized_start=698
  _NAMEDRULEWITHOPERATIONS._serialized_end=900
  _PARAMKIND._serialized_start=902
  _PARAMKIND._serialized_end=1005
  _PARAMREF._serialized_start=1007
  _PARAMREF._serialized_end=1107
  _VALIDATINGADMISSIONPOLICY._serialized_start=1110
  _VALIDATINGADMISSIONPOLICY._serialized_end=1403
  _VALIDATINGADMISSIONPOLICYBINDING._serialized_start=1406
  _VALIDATINGADMISSIONPOLICYBINDING._serialized_end=1713
  _VALIDATINGADMISSIONPOLICYBINDINGLIST._serialized_start=1716
  _VALIDATINGADMISSIONPOLICYBINDINGLIST._serialized_end=2022
  _VALIDATINGADMISSIONPOLICYBINDINGSPEC._serialized_start=2025
  _VALIDATINGADMISSIONPOLICYBINDINGSPEC._serialized_end=2315
  _VALIDATINGADMISSIONPOLICYLIST._serialized_start=2318
  _VALIDATINGADMISSIONPOLICYLIST._serialized_end=2610
  _VALIDATINGADMISSIONPOLICYSPEC._serialized_start=2613
  _VALIDATINGADMISSIONPOLICYSPEC._serialized_end=2988
  _VALIDATION._serialized_start=2990
  _VALIDATION._serialized_end=3112
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeBackendBucketXCdnPolicyXBypassCacheOnRequestHeaders(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name"]) -> None: ...

global___ComputeBackendBucketXCdnPolicyXBypassCacheOnRequestHeaders = ComputeBackendBucketXCdnPolicyXBypassCacheOnRequestHeaders

@typing_extensions.final
class ComputeBackendBucketXCdnPolicyXCacheKeyPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INCLUDE_HTTP_HEADERS_FIELD_NUMBER: builtins.int
    QUERY_STRING_WHITELIST_FIELD_NUMBER: builtins.int
    @property
    def include_http_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def query_string_whitelist(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        include_http_headers: collections.abc.Iterable[builtins.str] | None = ...,
        query_string_whitelist: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["include_http_headers", b"include_http_headers", "query_string_whitelist", b"query_string_whitelist"]) -> None: ...

global___ComputeBackendBucketXCdnPolicyXCacheKeyPolicy = ComputeBackendBucketXCdnPolicyXCacheKeyPolicy

@typing_extensions.final
class ComputeBackendBucketXCdnPolicyXNegativeCachingPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    code: builtins.float
    ttl: builtins.float
    def __init__(
        self,
        *,
        code: builtins.float = ...,
        ttl: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "ttl", b"ttl"]) -> None: ...

global___ComputeBackendBucketXCdnPolicyXNegativeCachingPolicy = ComputeBackendBucketXCdnPolicyXNegativeCachingPolicy

@typing_extensions.final
class ComputeBackendBucketXCdnPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CACHE_MODE_FIELD_NUMBER: builtins.int
    CLIENT_TTL_FIELD_NUMBER: builtins.int
    DEFAULT_TTL_FIELD_NUMBER: builtins.int
    MAX_TTL_FIELD_NUMBER: builtins.int
    NEGATIVE_CACHING_FIELD_NUMBER: builtins.int
    REQUEST_COALESCING_FIELD_NUMBER: builtins.int
    SERVE_WHILE_STALE_FIELD_NUMBER: builtins.int
    SIGNED_URL_CACHE_MAX_AGE_SEC_FIELD_NUMBER: builtins.int
    BYPASS_CACHE_ON_REQUEST_HEADERS_FIELD_NUMBER: builtins.int
    CACHE_KEY_POLICY_FIELD_NUMBER: builtins.int
    NEGATIVE_CACHING_POLICY_FIELD_NUMBER: builtins.int
    cache_mode: builtins.str
    client_ttl: builtins.float
    default_ttl: builtins.float
    max_ttl: builtins.float
    negative_caching: builtins.bool
    request_coalescing: builtins.bool
    serve_while_stale: builtins.float
    signed_url_cache_max_age_sec: builtins.float
    @property
    def bypass_cache_on_request_headers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeBackendBucketXCdnPolicyXBypassCacheOnRequestHeaders]: ...
    @property
    def cache_key_policy(self) -> global___ComputeBackendBucketXCdnPolicyXCacheKeyPolicy: ...
    @property
    def negative_caching_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeBackendBucketXCdnPolicyXNegativeCachingPolicy]: ...
    def __init__(
        self,
        *,
        cache_mode: builtins.str = ...,
        client_ttl: builtins.float = ...,
        default_ttl: builtins.float = ...,
        max_ttl: builtins.float = ...,
        negative_caching: builtins.bool = ...,
        request_coalescing: builtins.bool = ...,
        serve_while_stale: builtins.float = ...,
        signed_url_cache_max_age_sec: builtins.float = ...,
        bypass_cache_on_request_headers: collections.abc.Iterable[global___ComputeBackendBucketXCdnPolicyXBypassCacheOnRequestHeaders] | None = ...,
        cache_key_policy: global___ComputeBackendBucketXCdnPolicyXCacheKeyPolicy | None = ...,
        negative_caching_policy: collections.abc.Iterable[global___ComputeBackendBucketXCdnPolicyXNegativeCachingPolicy] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cache_key_policy", b"cache_key_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bypass_cache_on_request_headers", b"bypass_cache_on_request_headers", "cache_key_policy", b"cache_key_policy", "cache_mode", b"cache_mode", "client_ttl", b"client_ttl", "default_ttl", b"default_ttl", "max_ttl", b"max_ttl", "negative_caching", b"negative_caching", "negative_caching_policy", b"negative_caching_policy", "request_coalescing", b"request_coalescing", "serve_while_stale", b"serve_while_stale", "signed_url_cache_max_age_sec", b"signed_url_cache_max_age_sec"]) -> None: ...

global___ComputeBackendBucketXCdnPolicy = ComputeBackendBucketXCdnPolicy

@typing_extensions.final
class ComputeBackendBucketXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeBackendBucketXTimeouts = ComputeBackendBucketXTimeouts

@typing_extensions.final
class ComputeBackendBucket(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_NAME_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    CUSTOM_RESPONSE_HEADERS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EDGE_SECURITY_POLICY_FIELD_NUMBER: builtins.int
    ENABLE_CDN_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    CDN_POLICY_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    bucket_name: builtins.str
    creation_timestamp: builtins.str
    @property
    def custom_response_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    description: builtins.str
    edge_security_policy: builtins.str
    enable_cdn: builtins.bool
    id: builtins.str
    name: builtins.str
    project: builtins.str
    self_link: builtins.str
    @property
    def cdn_policy(self) -> global___ComputeBackendBucketXCdnPolicy: ...
    @property
    def timeouts(self) -> global___ComputeBackendBucketXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        bucket_name: builtins.str = ...,
        creation_timestamp: builtins.str = ...,
        custom_response_headers: collections.abc.Iterable[builtins.str] | None = ...,
        description: builtins.str = ...,
        edge_security_policy: builtins.str = ...,
        enable_cdn: builtins.bool = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        cdn_policy: global___ComputeBackendBucketXCdnPolicy | None = ...,
        timeouts: global___ComputeBackendBucketXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cdn_policy", b"cdn_policy", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_name", b"bucket_name", "cdn_policy", b"cdn_policy", "creation_timestamp", b"creation_timestamp", "custom_response_headers", b"custom_response_headers", "description", b"description", "edge_security_policy", b"edge_security_policy", "enable_cdn", b"enable_cdn", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "timeouts", b"timeouts"]) -> None: ...

global___ComputeBackendBucket = ComputeBackendBucket

@typing_extensions.final
class ComputeBackendBucketSignedUrlKeyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeBackendBucketSignedUrlKeyXTimeouts = ComputeBackendBucketSignedUrlKeyXTimeouts

@typing_extensions.final
class ComputeBackendBucketSignedUrlKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_BUCKET_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    KEY_VALUE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    backend_bucket: builtins.str
    id: builtins.str
    key_value: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def timeouts(self) -> global___ComputeBackendBucketSignedUrlKeyXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        backend_bucket: builtins.str = ...,
        id: builtins.str = ...,
        key_value: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        timeouts: global___ComputeBackendBucketSignedUrlKeyXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_bucket", b"backend_bucket", "id", b"id", "key_value", b"key_value", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ComputeBackendBucketSignedUrlKey = ComputeBackendBucketSignedUrlKey

@typing_extensions.final
class ComputeBackendServiceXBackend(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BALANCING_MODE_FIELD_NUMBER: builtins.int
    CAPACITY_SCALER_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    MAX_CONNECTIONS_FIELD_NUMBER: builtins.int
    MAX_CONNECTIONS_PER_ENDPOINT_FIELD_NUMBER: builtins.int
    MAX_CONNECTIONS_PER_INSTANCE_FIELD_NUMBER: builtins.int
    MAX_RATE_FIELD_NUMBER: builtins.int
    MAX_RATE_PER_ENDPOINT_FIELD_NUMBER: builtins.int
    MAX_RATE_PER_INSTANCE_FIELD_NUMBER: builtins.int
    MAX_UTILIZATION_FIELD_NUMBER: builtins.int
    balancing_mode: builtins.str
    capacity_scaler: builtins.float
    description: builtins.str
    group: builtins.str
    max_connections: builtins.float
    max_connections_per_endpoint: builtins.float
    max_connections_per_instance: builtins.float
    max_rate: builtins.float
    max_rate_per_endpoint: builtins.float
    max_rate_per_instance: builtins.float
    max_utilization: builtins.float
    def __init__(
        self,
        *,
        balancing_mode: builtins.str = ...,
        capacity_scaler: builtins.float = ...,
        description: builtins.str = ...,
        group: builtins.str = ...,
        max_connections: builtins.float = ...,
        max_connections_per_endpoint: builtins.float = ...,
        max_connections_per_instance: builtins.float = ...,
        max_rate: builtins.float = ...,
        max_rate_per_endpoint: builtins.float = ...,
        max_rate_per_instance: builtins.float = ...,
        max_utilization: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["balancing_mode", b"balancing_mode", "capacity_scaler", b"capacity_scaler", "description", b"description", "group", b"group", "max_connections", b"max_connections", "max_connections_per_endpoint", b"max_connections_per_endpoint", "max_connections_per_instance", b"max_connections_per_instance", "max_rate", b"max_rate", "max_rate_per_endpoint", b"max_rate_per_endpoint", "max_rate_per_instance", b"max_rate_per_instance", "max_utilization", b"max_utilization"]) -> None: ...

global___ComputeBackendServiceXBackend = ComputeBackendServiceXBackend

@typing_extensions.final
class ComputeBackendServiceXCdnPolicyXCacheKeyPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INCLUDE_HOST_FIELD_NUMBER: builtins.int
    INCLUDE_NAMED_COOKIES_FIELD_NUMBER: builtins.int
    INCLUDE_PROTOCOL_FIELD_NUMBER: builtins.int
    INCLUDE_QUERY_STRING_FIELD_NUMBER: builtins.int
    QUERY_STRING_BLACKLIST_FIELD_NUMBER: builtins.int
    QUERY_STRING_WHITELIST_FIELD_NUMBER: builtins.int
    include_host: builtins.bool
    @property
    def include_named_cookies(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    include_protocol: builtins.bool
    include_query_string: builtins.bool
    @property
    def query_string_blacklist(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def query_string_whitelist(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        include_host: builtins.bool = ...,
        include_named_cookies: collections.abc.Iterable[builtins.str] | None = ...,
        include_protocol: builtins.bool = ...,
        include_query_string: builtins.bool = ...,
        query_string_blacklist: collections.abc.Iterable[builtins.str] | None = ...,
        query_string_whitelist: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["include_host", b"include_host", "include_named_cookies", b"include_named_cookies", "include_protocol", b"include_protocol", "include_query_string", b"include_query_string", "query_string_blacklist", b"query_string_blacklist", "query_string_whitelist", b"query_string_whitelist"]) -> None: ...

global___ComputeBackendServiceXCdnPolicyXCacheKeyPolicy = ComputeBackendServiceXCdnPolicyXCacheKeyPolicy

@typing_extensions.final
class ComputeBackendServiceXCdnPolicyXNegativeCachingPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    code: builtins.float
    ttl: builtins.float
    def __init__(
        self,
        *,
        code: builtins.float = ...,
        ttl: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "ttl", b"ttl"]) -> None: ...

global___ComputeBackendServiceXCdnPolicyXNegativeCachingPolicy = ComputeBackendServiceXCdnPolicyXNegativeCachingPolicy

@typing_extensions.final
class ComputeBackendServiceXCdnPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CACHE_MODE_FIELD_NUMBER: builtins.int
    CLIENT_TTL_FIELD_NUMBER: builtins.int
    DEFAULT_TTL_FIELD_NUMBER: builtins.int
    MAX_TTL_FIELD_NUMBER: builtins.int
    NEGATIVE_CACHING_FIELD_NUMBER: builtins.int
    SERVE_WHILE_STALE_FIELD_NUMBER: builtins.int
    SIGNED_URL_CACHE_MAX_AGE_SEC_FIELD_NUMBER: builtins.int
    CACHE_KEY_POLICY_FIELD_NUMBER: builtins.int
    NEGATIVE_CACHING_POLICY_FIELD_NUMBER: builtins.int
    cache_mode: builtins.str
    client_ttl: builtins.float
    default_ttl: builtins.float
    max_ttl: builtins.float
    negative_caching: builtins.bool
    serve_while_stale: builtins.float
    signed_url_cache_max_age_sec: builtins.float
    @property
    def cache_key_policy(self) -> global___ComputeBackendServiceXCdnPolicyXCacheKeyPolicy: ...
    @property
    def negative_caching_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeBackendServiceXCdnPolicyXNegativeCachingPolicy]: ...
    def __init__(
        self,
        *,
        cache_mode: builtins.str = ...,
        client_ttl: builtins.float = ...,
        default_ttl: builtins.float = ...,
        max_ttl: builtins.float = ...,
        negative_caching: builtins.bool = ...,
        serve_while_stale: builtins.float = ...,
        signed_url_cache_max_age_sec: builtins.float = ...,
        cache_key_policy: global___ComputeBackendServiceXCdnPolicyXCacheKeyPolicy | None = ...,
        negative_caching_policy: collections.abc.Iterable[global___ComputeBackendServiceXCdnPolicyXNegativeCachingPolicy] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cache_key_policy", b"cache_key_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cache_key_policy", b"cache_key_policy", "cache_mode", b"cache_mode", "client_ttl", b"client_ttl", "default_ttl", b"default_ttl", "max_ttl", b"max_ttl", "negative_caching", b"negative_caching", "negative_caching_policy", b"negative_caching_policy", "serve_while_stale", b"serve_while_stale", "signed_url_cache_max_age_sec", b"signed_url_cache_max_age_sec"]) -> None: ...

global___ComputeBackendServiceXCdnPolicy = ComputeBackendServiceXCdnPolicy

@typing_extensions.final
class ComputeBackendServiceXCircuitBreakers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_CONNECTIONS_FIELD_NUMBER: builtins.int
    MAX_PENDING_REQUESTS_FIELD_NUMBER: builtins.int
    MAX_REQUESTS_FIELD_NUMBER: builtins.int
    MAX_REQUESTS_PER_CONNECTION_FIELD_NUMBER: builtins.int
    MAX_RETRIES_FIELD_NUMBER: builtins.int
    max_connections: builtins.float
    max_pending_requests: builtins.float
    max_requests: builtins.float
    max_requests_per_connection: builtins.float
    max_retries: builtins.float
    def __init__(
        self,
        *,
        max_connections: builtins.float = ...,
        max_pending_requests: builtins.float = ...,
        max_requests: builtins.float = ...,
        max_requests_per_connection: builtins.float = ...,
        max_retries: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_connections", b"max_connections", "max_pending_requests", b"max_pending_requests", "max_requests", b"max_requests", "max_requests_per_connection", b"max_requests_per_connection", "max_retries", b"max_retries"]) -> None: ...

global___ComputeBackendServiceXCircuitBreakers = ComputeBackendServiceXCircuitBreakers

@typing_extensions.final
class ComputeBackendServiceXConsistentHashXHttpCookieXTtl(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.float
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeBackendServiceXConsistentHashXHttpCookieXTtl = ComputeBackendServiceXConsistentHashXHttpCookieXTtl

@typing_extensions.final
class ComputeBackendServiceXConsistentHashXHttpCookie(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    name: builtins.str
    path: builtins.str
    @property
    def ttl(self) -> global___ComputeBackendServiceXConsistentHashXHttpCookieXTtl: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        path: builtins.str = ...,
        ttl: global___ComputeBackendServiceXConsistentHashXHttpCookieXTtl | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ttl", b"ttl"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "path", b"path", "ttl", b"ttl"]) -> None: ...

global___ComputeBackendServiceXConsistentHashXHttpCookie = ComputeBackendServiceXConsistentHashXHttpCookie

@typing_extensions.final
class ComputeBackendServiceXConsistentHash(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_HEADER_NAME_FIELD_NUMBER: builtins.int
    MINIMUM_RING_SIZE_FIELD_NUMBER: builtins.int
    HTTP_COOKIE_FIELD_NUMBER: builtins.int
    http_header_name: builtins.str
    minimum_ring_size: builtins.float
    @property
    def http_cookie(self) -> global___ComputeBackendServiceXConsistentHashXHttpCookie: ...
    def __init__(
        self,
        *,
        http_header_name: builtins.str = ...,
        minimum_ring_size: builtins.float = ...,
        http_cookie: global___ComputeBackendServiceXConsistentHashXHttpCookie | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["http_cookie", b"http_cookie"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["http_cookie", b"http_cookie", "http_header_name", b"http_header_name", "minimum_ring_size", b"minimum_ring_size"]) -> None: ...

global___ComputeBackendServiceXConsistentHash = ComputeBackendServiceXConsistentHash

@typing_extensions.final
class ComputeBackendServiceXIap(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OAUTH2_CLIENT_ID_FIELD_NUMBER: builtins.int
    OAUTH2_CLIENT_SECRET_FIELD_NUMBER: builtins.int
    OAUTH2_CLIENT_SECRET_SHA256_FIELD_NUMBER: builtins.int
    oauth2_client_id: builtins.str
    oauth2_client_secret: builtins.str
    oauth2_client_secret_sha256: builtins.str
    def __init__(
        self,
        *,
        oauth2_client_id: builtins.str = ...,
        oauth2_client_secret: builtins.str = ...,
        oauth2_client_secret_sha256: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["oauth2_client_id", b"oauth2_client_id", "oauth2_client_secret", b"oauth2_client_secret", "oauth2_client_secret_sha256", b"oauth2_client_secret_sha256"]) -> None: ...

global___ComputeBackendServiceXIap = ComputeBackendServiceXIap

@typing_extensions.final
class ComputeBackendServiceXLogConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_FIELD_NUMBER: builtins.int
    SAMPLE_RATE_FIELD_NUMBER: builtins.int
    enable: builtins.bool
    sample_rate: builtins.float
    def __init__(
        self,
        *,
        enable: builtins.bool = ...,
        sample_rate: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable", b"enable", "sample_rate", b"sample_rate"]) -> None: ...

global___ComputeBackendServiceXLogConfig = ComputeBackendServiceXLogConfig

@typing_extensions.final
class ComputeBackendServiceXOutlierDetectionXBaseEjectionTime(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.float
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeBackendServiceXOutlierDetectionXBaseEjectionTime = ComputeBackendServiceXOutlierDetectionXBaseEjectionTime

@typing_extensions.final
class ComputeBackendServiceXOutlierDetectionXInterval(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.float
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeBackendServiceXOutlierDetectionXInterval = ComputeBackendServiceXOutlierDetectionXInterval

@typing_extensions.final
class ComputeBackendServiceXOutlierDetection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONSECUTIVE_ERRORS_FIELD_NUMBER: builtins.int
    CONSECUTIVE_GATEWAY_FAILURE_FIELD_NUMBER: builtins.int
    ENFORCING_CONSECUTIVE_ERRORS_FIELD_NUMBER: builtins.int
    ENFORCING_CONSECUTIVE_GATEWAY_FAILURE_FIELD_NUMBER: builtins.int
    ENFORCING_SUCCESS_RATE_FIELD_NUMBER: builtins.int
    MAX_EJECTION_PERCENT_FIELD_NUMBER: builtins.int
    SUCCESS_RATE_MINIMUM_HOSTS_FIELD_NUMBER: builtins.int
    SUCCESS_RATE_REQUEST_VOLUME_FIELD_NUMBER: builtins.int
    SUCCESS_RATE_STDEV_FACTOR_FIELD_NUMBER: builtins.int
    BASE_EJECTION_TIME_FIELD_NUMBER: builtins.int
    INTERVAL_FIELD_NUMBER: builtins.int
    consecutive_errors: builtins.float
    consecutive_gateway_failure: builtins.float
    enforcing_consecutive_errors: builtins.float
    enforcing_consecutive_gateway_failure: builtins.float
    enforcing_success_rate: builtins.float
    max_ejection_percent: builtins.float
    success_rate_minimum_hosts: builtins.float
    success_rate_request_volume: builtins.float
    success_rate_stdev_factor: builtins.float
    @property
    def base_ejection_time(self) -> global___ComputeBackendServiceXOutlierDetectionXBaseEjectionTime: ...
    @property
    def interval(self) -> global___ComputeBackendServiceXOutlierDetectionXInterval: ...
    def __init__(
        self,
        *,
        consecutive_errors: builtins.float = ...,
        consecutive_gateway_failure: builtins.float = ...,
        enforcing_consecutive_errors: builtins.float = ...,
        enforcing_consecutive_gateway_failure: builtins.float = ...,
        enforcing_success_rate: builtins.float = ...,
        max_ejection_percent: builtins.float = ...,
        success_rate_minimum_hosts: builtins.float = ...,
        success_rate_request_volume: builtins.float = ...,
        success_rate_stdev_factor: builtins.float = ...,
        base_ejection_time: global___ComputeBackendServiceXOutlierDetectionXBaseEjectionTime | None = ...,
        interval: global___ComputeBackendServiceXOutlierDetectionXInterval | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base_ejection_time", b"base_ejection_time", "interval", b"interval"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_ejection_time", b"base_ejection_time", "consecutive_errors", b"consecutive_errors", "consecutive_gateway_failure", b"consecutive_gateway_failure", "enforcing_consecutive_errors", b"enforcing_consecutive_errors", "enforcing_consecutive_gateway_failure", b"enforcing_consecutive_gateway_failure", "enforcing_success_rate", b"enforcing_success_rate", "interval", b"interval", "max_ejection_percent", b"max_ejection_percent", "success_rate_minimum_hosts", b"success_rate_minimum_hosts", "success_rate_request_volume", b"success_rate_request_volume", "success_rate_stdev_factor", b"success_rate_stdev_factor"]) -> None: ...

global___ComputeBackendServiceXOutlierDetection = ComputeBackendServiceXOutlierDetection

@typing_extensions.final
class ComputeBackendServiceXSecuritySettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_TLS_POLICY_FIELD_NUMBER: builtins.int
    SUBJECT_ALT_NAMES_FIELD_NUMBER: builtins.int
    client_tls_policy: builtins.str
    @property
    def subject_alt_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        client_tls_policy: builtins.str = ...,
        subject_alt_names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_tls_policy", b"client_tls_policy", "subject_alt_names", b"subject_alt_names"]) -> None: ...

global___ComputeBackendServiceXSecuritySettings = ComputeBackendServiceXSecuritySettings

@typing_extensions.final
class ComputeBackendServiceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeBackendServiceXTimeouts = ComputeBackendServiceXTimeouts

@typing_extensions.final
class ComputeBackendService(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AFFINITY_COOKIE_TTL_SEC_FIELD_NUMBER: builtins.int
    CONNECTION_DRAINING_TIMEOUT_SEC_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    CUSTOM_REQUEST_HEADERS_FIELD_NUMBER: builtins.int
    CUSTOM_RESPONSE_HEADERS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENABLE_CDN_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    HEALTH_CHECKS_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOAD_BALANCING_SCHEME_FIELD_NUMBER: builtins.int
    LOCALITY_LB_POLICY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PORT_NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    SECURITY_POLICY_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SESSION_AFFINITY_FIELD_NUMBER: builtins.int
    TIMEOUT_SEC_FIELD_NUMBER: builtins.int
    BACKEND_FIELD_NUMBER: builtins.int
    CDN_POLICY_FIELD_NUMBER: builtins.int
    CIRCUIT_BREAKERS_FIELD_NUMBER: builtins.int
    CONSISTENT_HASH_FIELD_NUMBER: builtins.int
    IAP_FIELD_NUMBER: builtins.int
    LOG_CONFIG_FIELD_NUMBER: builtins.int
    OUTLIER_DETECTION_FIELD_NUMBER: builtins.int
    SECURITY_SETTINGS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    affinity_cookie_ttl_sec: builtins.float
    connection_draining_timeout_sec: builtins.float
    creation_timestamp: builtins.str
    @property
    def custom_request_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def custom_response_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    description: builtins.str
    enable_cdn: builtins.bool
    fingerprint: builtins.str
    @property
    def health_checks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    id: builtins.str
    load_balancing_scheme: builtins.str
    locality_lb_policy: builtins.str
    name: builtins.str
    port_name: builtins.str
    project: builtins.str
    protocol: builtins.str
    security_policy: builtins.str
    self_link: builtins.str
    session_affinity: builtins.str
    timeout_sec: builtins.float
    @property
    def backend(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeBackendServiceXBackend]: ...
    @property
    def cdn_policy(self) -> global___ComputeBackendServiceXCdnPolicy: ...
    @property
    def circuit_breakers(self) -> global___ComputeBackendServiceXCircuitBreakers: ...
    @property
    def consistent_hash(self) -> global___ComputeBackendServiceXConsistentHash: ...
    @property
    def iap(self) -> global___ComputeBackendServiceXIap: ...
    @property
    def log_config(self) -> global___ComputeBackendServiceXLogConfig: ...
    @property
    def outlier_detection(self) -> global___ComputeBackendServiceXOutlierDetection: ...
    @property
    def security_settings(self) -> global___ComputeBackendServiceXSecuritySettings: ...
    @property
    def timeouts(self) -> global___ComputeBackendServiceXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        affinity_cookie_ttl_sec: builtins.float = ...,
        connection_draining_timeout_sec: builtins.float = ...,
        creation_timestamp: builtins.str = ...,
        custom_request_headers: collections.abc.Iterable[builtins.str] | None = ...,
        custom_response_headers: collections.abc.Iterable[builtins.str] | None = ...,
        description: builtins.str = ...,
        enable_cdn: builtins.bool = ...,
        fingerprint: builtins.str = ...,
        health_checks: collections.abc.Iterable[builtins.str] | None = ...,
        id: builtins.str = ...,
        load_balancing_scheme: builtins.str = ...,
        locality_lb_policy: builtins.str = ...,
        name: builtins.str = ...,
        port_name: builtins.str = ...,
        project: builtins.str = ...,
        protocol: builtins.str = ...,
        security_policy: builtins.str = ...,
        self_link: builtins.str = ...,
        session_affinity: builtins.str = ...,
        timeout_sec: builtins.float = ...,
        backend: collections.abc.Iterable[global___ComputeBackendServiceXBackend] | None = ...,
        cdn_policy: global___ComputeBackendServiceXCdnPolicy | None = ...,
        circuit_breakers: global___ComputeBackendServiceXCircuitBreakers | None = ...,
        consistent_hash: global___ComputeBackendServiceXConsistentHash | None = ...,
        iap: global___ComputeBackendServiceXIap | None = ...,
        log_config: global___ComputeBackendServiceXLogConfig | None = ...,
        outlier_detection: global___ComputeBackendServiceXOutlierDetection | None = ...,
        security_settings: global___ComputeBackendServiceXSecuritySettings | None = ...,
        timeouts: global___ComputeBackendServiceXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cdn_policy", b"cdn_policy", "circuit_breakers", b"circuit_breakers", "consistent_hash", b"consistent_hash", "iap", b"iap", "log_config", b"log_config", "outlier_detection", b"outlier_detection", "resource_info", b"resource_info", "security_settings", b"security_settings", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["affinity_cookie_ttl_sec", b"affinity_cookie_ttl_sec", "backend", b"backend", "cdn_policy", b"cdn_policy", "circuit_breakers", b"circuit_breakers", "connection_draining_timeout_sec", b"connection_draining_timeout_sec", "consistent_hash", b"consistent_hash", "creation_timestamp", b"creation_timestamp", "custom_request_headers", b"custom_request_headers", "custom_response_headers", b"custom_response_headers", "description", b"description", "enable_cdn", b"enable_cdn", "fingerprint", b"fingerprint", "health_checks", b"health_checks", "iap", b"iap", "id", b"id", "load_balancing_scheme", b"load_balancing_scheme", "locality_lb_policy", b"locality_lb_policy", "log_config", b"log_config", "name", b"name", "outlier_detection", b"outlier_detection", "port_name", b"port_name", "project", b"project", "protocol", b"protocol", "resource_info", b"resource_info", "security_policy", b"security_policy", "security_settings", b"security_settings", "self_link", b"self_link", "session_affinity", b"session_affinity", "timeout_sec", b"timeout_sec", "timeouts", b"timeouts"]) -> None: ...

global___ComputeBackendService = ComputeBackendService

@typing_extensions.final
class ComputeBackendServiceSignedUrlKeyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeBackendServiceSignedUrlKeyXTimeouts = ComputeBackendServiceSignedUrlKeyXTimeouts

@typing_extensions.final
class ComputeBackendServiceSignedUrlKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_SERVICE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    KEY_VALUE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    backend_service: builtins.str
    id: builtins.str
    key_value: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def timeouts(self) -> global___ComputeBackendServiceSignedUrlKeyXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        backend_service: builtins.str = ...,
        id: builtins.str = ...,
        key_value: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        timeouts: global___ComputeBackendServiceSignedUrlKeyXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_service", b"backend_service", "id", b"id", "key_value", b"key_value", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ComputeBackendServiceSignedUrlKey = ComputeBackendServiceSignedUrlKey
